@@ -948,8 +948,8 @@ void pidof_usage(void)
 {
    printf("pidof usage: [options] <program-name>\n\n");
    printf(" -c           Return PIDs with the same root directory\n");
+   printf(" -d <sep>     Use the provided character as output separator\n");
    printf(" -h           Display this help text\n");
-   printf(" -f <format>  Display PIDs in a given printf-style format\n");
    printf(" -n           Avoid using stat system function on network shares\n");
    printf(" -o <pid>     Omit results with a given PID\n");
    printf(" -q           Quiet mode. Do not display output\n");
@@ -999,7 +999,7 @@ int main_pidof(int argc, char **argv)
 	int		chroot_check = 0;
 	struct stat	st;
 	char		tmp[512];
-        char            *format = NULL;
+        char            sep = ' ';
 
 	omit = (OMIT*)0;
 	nlist = (NFS*)0;
@@ -1008,7 +1008,7 @@ int main_pidof(int argc, char **argv)
 	if ((token = getenv("PIDOF_NETFS")) && (strcmp(token,"no") != 0))
 		flags |= PIDOF_NETFS;
 
-	while ((opt = getopt(argc,argv,"qhco:f:sxn")) != EOF) switch (opt) {
+	while ((opt = getopt(argc,argv,"qhco:d:sxn")) != EOF) switch (opt) {
 		case '?':
 			nsyslog(LOG_ERR,"invalid options on command line!\n");
 			closelog();
@@ -1019,8 +1019,8 @@ int main_pidof(int argc, char **argv)
                 case 'h':
                         pidof_usage();
                         exit(0);
-                case 'f':
-                        format = optarg;
+                case 'd':
+                        sep = optarg[0];
                         break;
 		case 'o':
 			here = optarg;
@@ -1118,14 +1118,9 @@ int main_pidof(int argc, char **argv)
 				}
 
 				if ( ~flags & PIDOF_QUIET ) {
-                                    if (format)
-                                       printf(format, p->pid);
-                                    else
-                                    {
 					if (! first)
-						printf(" ");
+						printf("%c", sep);
 					printf("%d", p->pid);
-                                    }
 				}
 				first = 0;
 			}
